@@ -10,7 +10,9 @@ import argparse
 import argcomplete
 import IPython
 from pathlib import Path 
+import subprocess
 
+os.popen("eval $(register-python-argcomplete copy-to)").read()
 file=os.path.expanduser("~/.config/copy_to/confs.json")
 complete=os.path.expanduser("~/.config/copy_to/")
 folder=os.path.expanduser("~/.config/copy_to/")
@@ -173,7 +175,7 @@ def get_main_parser():
     return parser
 
 def main():
-
+    os.popen("eval $(register-python-argcomplete copy-to)").read()
     """from os.path import dirname, abspath
     d = dirname(abspath(__file__))
 
@@ -240,8 +242,8 @@ def main():
         if not 'name' in args:
             print("Give up a configuration name to copy objects between")
             raise SystemExit
-        elif args.name == 'group':
-            print("Name 'group' is reserved to keep track of groupnames")
+        elif args.name == 'group' or args.name == 'all':
+            print("Name 'group' and 'all' are reserved in namespace")
             raise SystemExit
         elif name in envs:
             print("Look again. " + str(name) + " is/are already used as name.")
@@ -268,8 +270,8 @@ def main():
         if not 'groupname' in args:
             print("Give up an configuration to copy objects between")
             raise SystemExit
-        elif args.groupname == 'group':
-            print("Name 'group' is reserved to keep track of groupnames")
+        elif args.groupname == 'group' or args.groupname == 'all' :
+            print("Name 'group' and 'all' are reserved in namespace")
             raise SystemExit
         elif args.groupname in envs:
             print("Can't have both the same groupname and regular name. Change " + str(args.groupname))
